package com.vandyo.sentry.core.cases;

import cn.hutool.http.HttpRequest;
import cn.hutool.http.HttpResponse;
import cn.hutool.json.JSONObject;
import cn.hutool.json.JSONUtil;
import com.vandyo.sentry.core.dto.ErrStatus;
import com.vandyo.sentry.core.dto.Res;
import com.vandyo.sentry.core.exceptions.CaseException;
import com.vandyo.sentry.core.tools.Signature;

import java.util.HashMap;
import java.util.Map;

/**
 * 获取Banner列表接口
 */
public class BannerListDecorator extends CaseDecorator {

    private final static String bannerListUrl = "/user/banner/list";

    public BannerListDecorator(Case aCase) {
        super(aCase);
    }

    @Override
    public Res<Map<String, String>> check() throws CaseException {
        Res<Map<String, String>> oldRes = super.check();
        if (oldRes.getSuccess()) {
            Map<String, String> carMap = oldRes.getData();
            Res<Map<String, String>> newRes = new Res<>();
            newRes.setSId(oldRes.getSId());
            newRes.setUId(oldRes.getUId());
            Map<String, String> paramMap = new HashMap<>();
            paramMap.put("uid", oldRes.getUId());
            paramMap.put("type", "1");
            try {
                HttpResponse response = HttpRequest.post(Signature.host + bannerListUrl)
                        .body(JSONUtil.parseFromMap(paramMap).toString())
                        .execute();
                if (response.isOk()) {
                    JSONObject jsonObject = JSONUtil.parseObj(response.body());
                    //todo 检测 返回值可用性
                    newRes.setData(carMap);
                    newRes.setSuccess(true);
                } else {
                    newRes.setKey(bannerListUrl);
                    newRes.setStatus(Signature.matchStatus(response.getStatus()));
                    newRes.setSuccess(false);
                }
                return newRes;
            }catch (Exception e){
                if (e.getMessage().toLowerCase().contains("timeout")){
                    throw new CaseException(bannerListUrl, ErrStatus.ErrTimeout);
                }else {
                    throw new CaseException(bannerListUrl,ErrStatus.ErrUnknown);
                }
            }
        } else {
            oldRes.setIgnore(true);
            return oldRes;
        }
    }
}
